Date: 2007-10-16

# latua documentation

## Installation

Contact: | team@petunial.com
Date: | 2007-10-16
Status: | This is a "work in progress"
Revision: | 292
Copyright: | BSD License

Dedication

For system administrators.

Abstract

This document describes how to install latua.

Table of Contents

# 1 Supported platforms

latua should run on the following platforms:

> - Linux
> - Windows
> - Mac Os X
> - OpenBSD

Other platforms should work too, but are not official supported.

# 2 Requirements

The following software is required to run latua:

> - Python >=2.5 from [http://www.python.org/]

Python 2.4 should work too, but is not official supported because it does not contain the sqlite3 core module. Running latua with Python 2.4 requires pysqlite from [http://www.initd.org/tracker/pysqlite] for the indexer module.

## 2.1 Windows dependencies

Running latua under windows requires:

> - Python Win32 Extensions from [https://sourceforge.net/projects/pywin32/]

# 3 Packages installation

latua is available as package for various operating systems and distributions.

## 3.1 Windows

Just download and run: `latua-version.win32.exe`.

## 3.2 Linux RPM

Download the `latua-version.noarch.rpm` package and use the following command for installation:

    # rpm -ihv latua-version.noarch.rpm

# 4 Source installation

Extract latua sources:

    # tar xzvf latua-version.tar.gz

Installation via python distutils:

    # cd latua-version
    # python setup.py install

Optional: run test suite before (or after) installation:

    # python test/test